package org.apache.maven.j2ee;

/* ====================================================================
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 2002 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Apache" and "Apache Software Foundation" and
 *    "Apache Maven" must not be used to endorse or promote products
 *    derived from this software without prior written permission. For
 *    written permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    "Apache Maven", nor may "Apache" appear in their name, without
 *    prior written permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

import junit.framework.TestCase;

/** 
 * Unit test for {@link ValidationStatusListener}.
 * 
 * @author <a href="mailto:dion@multitask.com.au">dIon Gillard</a>
 * @version $Id: ValidationStatusListenerTest.java,v 1.1 2003/01/24 03:45:19 jvanzyl Exp $
 */
public class ValidationStatusListenerTest extends TestCase
{
    /** instance used for testing */
    private ValidationStatusListener instance;
    
    /** 
     * Creates a new instance of ValidationStatusListenerTest
     * @param testName the name of the test
     */
    public ValidationStatusListenerTest(String testName)
    {
        super(testName);
    }

    /**
     * test that the zero arg constructor works
     * @throws Exception when there is an unexpected problem
     */
    public void testDefaultConstructor() throws Exception
    {
        instance = new ValidationStatusListener();
        assertNotNull("Constructor hasn't returned a value", instance);
        assertEquals("started property isn't false", false, 
            instance.isStarted());
        assertEquals("error property isn't false", false, instance.isError());
        assertEquals("warning property isn't false", false,
            instance.isWarning());
        assertEquals("ended property isn't false", false, instance.isEnded());
    }
    
    /**
     * test that the listener handles validation started events correctly
     * @throws Exception when there is an unexpected problem
     */
    public void testStarted() throws Exception
    {
        instance = new ValidationStatusListener();
        instance.validationStarted(new ValidationEvent(this));
        assertTrue("started property is not being set", instance.isStarted()); 
    }
    
    /**
     * test that the listener handles validation error events correctly
     * @throws Exception when there is an unexpected problem
     */
    public void testError() throws Exception
    {
        testStarted();
        instance.validationError(new ValidationEvent(this));
        assertTrue("error property is not being set", instance.isError()); 
    }
    
    /**
     * test that the listener handles validation warning events correctly
     * @throws Exception when there is an unexpected problem
     */
    public void testWarning() throws Exception
    {
        testStarted();
        instance.validationWarning(new ValidationEvent(this));
        assertTrue("warning property is not being set", instance.isWarning());
    }

    /**
     * test that the listener handles validation ended events correctly
     * @throws Exception when there is an unexpected problem
     */
    public void testEnded() throws Exception
    {
        testStarted();
        instance.validationEnded(new ValidationEvent(this));
        assertTrue("ended property is not being set", instance.isEnded());
    }

}
